import React, { PureComponent } from "react";
import { View } from "react-native";
import HTMLView from "rn-fast-htmlview";
import cleanHtml from "clean-html-js";
import { Body, Loader } from "./components";
import { styles } from "./styles/main";
class ReadabilityView extends PureComponent {
    constructor(props) {
        super(props);
        this.mounted = false;
        this.parseHtml = this.parseHtml.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        if (!this.props.lazy) {
            this.parseHtml();
        }
    }
    componentWillUnmount() {
        this.mounted = false;
    }
    componentDidUpdate(prevProps) {
        if (this.props.url !== prevProps.url ||
            this.props.html !== prevProps.html ||
            this.props.lazy !== prevProps.lazy) {
            this.parseHtml();
        }
    }
    async getData() {
        const { url } = this.props;
        try {
            const response = await fetch(url);
            return await response.text();
        }
        catch (error) {
            this.logError(error);
        }
    }
    async parseHtml() {
        const { config, url, html } = this.props;
        let htmlContent = html;
        if (!htmlContent) {
            try {
                htmlContent = await this.getData();
            }
            catch (error) {
                this.logError(error);
            }
        }
        if (htmlContent) {
            try {
                const readabilityArticle = await cleanHtml(htmlContent, url, config);
                this.setView(readabilityArticle);
            }
            catch (error) {
                this.logError(error);
            }
        }
    }
    setView(readabilityArticle) {
        this.mounted &&
            this.setState({
                cleanHtmlSource: !readabilityArticle
                    ? this.props.errorPage ||
                        `<h1>Sorry, issue parsing ${this.props.url}</h1>`
                    : readabilityArticle.content,
            });
    }
    logError(error) {
        const { onError } = this.props;
        typeof onError === "function" ? onError(error) : console.error(error);
        this.setView(null);
    }
    render() {
        const cleanHtmlSource = this.state && this.state.cleanHtmlSource;
        const props = { ...this.props, styles };
        return (<View style={[styles.flex, this.props.containerStyle]}>
        {!cleanHtmlSource ? (<Loader {...props}/>) : (<Body {...props}>
            <HTMLView value={cleanHtmlSource} {...this.props}/>
          </Body>)}
      </View>);
    }
}
export default ReadabilityView;
//# sourceMappingURL=reader.js.map